searchData={"items":[{"type":"module","title":"SilverOrb","doc":"WebAssembly is low level — you essentially get to define global variables, an array of memory, and some functions to operate on them. It’s not batteries-included.\n\n`SilverOrb` provides several extra batteries so common tasks are easier. They are:\n\n- `SilverOrb.Arena` allocator for memory management.\n- `SilverOrb.ASCII` (coming soon) for operating on ASCII strings.\n- `SilverOrb.UTF8` (coming soon) for operating on UTF-8 strings.\n- `SilverOrb.IntFormatter` for converting integers to strings.\n- `SilverOrb.IntParser` (coming soon) for converting strings to integers.\n- `SilverOrb.StringBuilder` for assembling strings from dynamic parts.\n- `SilverOrb.XMLBuilder` (coming soon) for assembling XML from dynamic parts.\n- `SilverOrb.FormData` (coming soon) for decoding/encoding `application/x-www-form-urlencoded` strings.\n- `SilverOrb.URLSearchParams` (coming soon) for decoding/encoding URL query strings.\n- `SilverOrb.URL` (coming soon) for decoding/encoding URLs.\n- `SilverOrb.Request` (coming soon) for encoding HTTP/1 requests.\n- `SilverOrb.Response` (coming soon) for encoding HTTP/1 responses.\n- `SilverOrb.Iterator` (coming soon) for creating a custom sequence type that can be iterated through.","ref":"SilverOrb.html"},{"type":"module","title":"SilverOrb.ASCII","doc":"","ref":"SilverOrb.ASCII.html"},{"type":"function","title":"SilverOrb.ASCII.lowercase/1","doc":"","ref":"SilverOrb.ASCII.html#lowercase/1"},{"type":"function","title":"SilverOrb.ASCII.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.ASCII.html#to_wat/0"},{"type":"function","title":"SilverOrb.ASCII.uppercase8/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase8/1"},{"type":"function","title":"SilverOrb.ASCII.uppercase32/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase32/1"},{"type":"function","title":"SilverOrb.ASCII.uppercase64/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase64/1"},{"type":"function","title":"SilverOrb.ASCII.uppercase/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase/1"},{"type":"module","title":"SilverOrb.Arena","doc":"Arena allocation.\n\nSee https://www.rfleury.com/p/untangling-lifetimes-the-arena-allocator\n\n```elixir\ndefmodule ArenaExample do\n  SilverOrb.Arena.def(First, pages: 2)\n  SilverOrb.Arena.def(Second, pages: 4, max_pages: 10)\n\n  defw example(), a: I32.UnsafePointer, b: I32.UnsafePointer do\n    a = First.alloc(4)\n    Memory.store!(I32, a, 42)\n\n    b = Second.alloc(4)\n    Memory.store!(I32, b, 99)\n\n    assert!(a !== First.alloc(4))\n    First.rewind()\n    assert!(a === First.alloc(4))\n  end\nend\n```","ref":"SilverOrb.Arena.html"},{"type":"macro","title":"SilverOrb.Arena.def/2","doc":"Defines an arena of memory. An Elixir module with your passed `name` is defined with `alloc!/1` and `rewind/0` functions.","ref":"SilverOrb.Arena.html#def/2"},{"type":"macro","title":"Options - SilverOrb.Arena.def/2","doc":"When defining an arena, two options can be given:\n\n- `:pages` — The number of pages to allocate for this arena. The global memory is increased by this count.\n- `:max_pages` — The maxmimum number of pages this can increase the global memory by using `Orb.Memory.grow!/1`. Only the last arena can support `max_pages`, as otherwise multiple arenas each growing in size will end up overlapping.","ref":"SilverOrb.Arena.html#def/2-options"},{"type":"function","title":"SilverOrb.Arena.inline_string_match/3","doc":"","ref":"SilverOrb.Arena.html#inline_string_match/3"},{"type":"macro","title":"SilverOrb.Arena.match_string/3","doc":"Match strings to content of passed `arena_mod`.","ref":"SilverOrb.Arena.html#match_string/3"},{"type":"function","title":"SilverOrb.Arena.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.Arena.html#to_wat/0"},{"type":"module","title":"SilverOrb.BumpAllocator","doc":"A bump allocator for Orb modules.\n\n```elixir\ndefmodule Example do\n  use Orb\n  use SilverOrb.BumpAllocator\n\nend\n```","ref":"SilverOrb.BumpAllocator.html"},{"type":"function","title":"SilverOrb.BumpAllocator.alloc/1","doc":"","ref":"SilverOrb.BumpAllocator.html#alloc/1"},{"type":"macro","title":"SilverOrb.BumpAllocator.export_alloc/0","doc":"","ref":"SilverOrb.BumpAllocator.html#export_alloc/0"},{"type":"function","title":"SilverOrb.BumpAllocator.free_all/0","doc":"","ref":"SilverOrb.BumpAllocator.html#free_all/0"},{"type":"function","title":"SilverOrb.BumpAllocator.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.BumpAllocator.html#to_wat/0"},{"type":"module","title":"SilverOrb.BumpAllocator.Constants","doc":"","ref":"SilverOrb.BumpAllocator.Constants.html"},{"type":"function","title":"SilverOrb.BumpAllocator.Constants.bump_init_offset/0","doc":"","ref":"SilverOrb.BumpAllocator.Constants.html#bump_init_offset/0"},{"type":"module","title":"SilverOrb.IntFormatter","doc":"","ref":"SilverOrb.IntFormatter.html"},{"type":"function","title":"SilverOrb.IntFormatter.format_u32/2","doc":"","ref":"SilverOrb.IntFormatter.html#format_u32/2"},{"type":"function","title":"SilverOrb.IntFormatter.format_u32_char_count/1","doc":"","ref":"SilverOrb.IntFormatter.html#format_u32_char_count/1"},{"type":"function","title":"SilverOrb.IntFormatter.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.IntFormatter.html#to_wat/0"},{"type":"module","title":"SilverOrb.Mem","doc":"memcpy and memset for Orb.\n\n```elixir\ndefmodule Example do\n  use Orb\n  use SilverOrb.Mem\n\nend\n```","ref":"SilverOrb.Mem.html"},{"type":"function","title":"SilverOrb.Mem.memcpy/1","doc":"","ref":"SilverOrb.Mem.html#memcpy/1"},{"type":"function","title":"SilverOrb.Mem.memcpy/3","doc":"","ref":"SilverOrb.Mem.html#memcpy/3"},{"type":"function","title":"SilverOrb.Mem.memset/1","doc":"","ref":"SilverOrb.Mem.html#memset/1"},{"type":"function","title":"SilverOrb.Mem.memset/3","doc":"","ref":"SilverOrb.Mem.html#memset/3"},{"type":"function","title":"SilverOrb.Mem.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.Mem.html#to_wat/0"},{"type":"module","title":"SilverOrb.Sort","doc":"","ref":"SilverOrb.Sort.html"},{"type":"function","title":"SilverOrb.Sort.bubble_sort/1","doc":"","ref":"SilverOrb.Sort.html#bubble_sort/1"},{"type":"module","title":"SilverOrb.StringBuilder","doc":"Build strings with dynamic content.\n\nHere’s an example with components rendering dynamic HTML:\n\n```elixir\ndefmodule HelloWorldComponent do\n  use Orb\n  use SilverOrb.StringBuilder\n\n  defwp daytime?(hour: I32), I32 do\n    hour >= 6 &&& hour <= 19\n  end\n\n  defw render(hour: I32), StringBuilder do\n    StringBuilder.build! do\n      \" \"\n\n      if daytime?(hour) do\n        \"Hello 🌞 sunny world\"\n      else\n        \"Hello 🌛 moonlit world\"\n      end\n\n      \" \\n\"\n    end\n  end\nend\n\ndefmodule DynamicHTMLPage do\n  use Orb\n  use SilverOrb.StringBuilder\n\n  Orb.include(HelloWorldComponent)\n\n  global do\n    @hour_of_day 8\n  end\n\n  defw set_hour_of_day(hour: I32) do\n    @hour_of_day = hour\n  end\n\n  defw text_html(), StringBuilder do\n    StringBuilder.build! do\n      \"\"\"\n      <!doctype html>\n       \n      \"\"\"\n\n      HelloWorldComponent.render(@hour_of_day)\n    end\n  end\nend\n```","ref":"SilverOrb.StringBuilder.html"},{"type":"function","title":"SilverOrb.StringBuilder.append!/1","doc":"","ref":"SilverOrb.StringBuilder.html#append!/1"},{"type":"function","title":"SilverOrb.StringBuilder.append!/2","doc":"","ref":"SilverOrb.StringBuilder.html#append!/2"},{"type":"function","title":"SilverOrb.StringBuilder.append!/3","doc":"","ref":"SilverOrb.StringBuilder.html#append!/3"},{"type":"function","title":"SilverOrb.StringBuilder.append!/4","doc":"","ref":"SilverOrb.StringBuilder.html#append!/4"},{"type":"function","title":"SilverOrb.StringBuilder.appended?/0","doc":"","ref":"SilverOrb.StringBuilder.html#appended?/0"},{"type":"macro","title":"SilverOrb.StringBuilder.build!/1","doc":"","ref":"SilverOrb.StringBuilder.html#build!/1"},{"type":"function","title":"SilverOrb.StringBuilder.build_begin!/0","doc":"","ref":"SilverOrb.StringBuilder.html#build_begin!/0"},{"type":"function","title":"SilverOrb.StringBuilder.build_done!/0","doc":"","ref":"SilverOrb.StringBuilder.html#build_done!/0"},{"type":"function","title":"SilverOrb.StringBuilder.build_item/1","doc":"","ref":"SilverOrb.StringBuilder.html#build_item/1"},{"type":"function","title":"SilverOrb.StringBuilder.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.StringBuilder.html#to_wat/0"},{"type":"module","title":"SilverOrb.StringBuilder.Constants","doc":"","ref":"SilverOrb.StringBuilder.Constants.html"},{"type":"function","title":"SilverOrb.StringBuilder.Constants.init_offset/0","doc":"","ref":"SilverOrb.StringBuilder.Constants.html#init_offset/0"},{"type":"module","title":"SilverOrb.StringBuilder.DSL","doc":"","ref":"SilverOrb.StringBuilder.DSL.html"},{"type":"macro","title":"SilverOrb.StringBuilder.DSL.if/2","doc":"","ref":"SilverOrb.StringBuilder.DSL.html#if/2"},{"type":"extras","title":"🕸️🔋 SilverOrb: the standard library for <a href=\"https://github.com/RoyalIcing/Orb\">Orb</a>","doc":"🕸️🔋 SilverOrb: the standard library for  Orb  \n\n  Docs  \n\nWebAssembly is low level — you essentially get to define global variables, an array of memory, and some functions to operate on them. It’s not batteries-included.\n\nSilverOrb provides these batteries so common tasks are easier. They are:\n\n- `StringBuilder` for assembling strings from dynamic parts.\n- `IntFormatter` for converting integers to strings.\n- `Arena` allocator for memory management.\n- `ASCII` (coming soon) for operating on ASCII strings.\n- `UTF8` (coming soon) for operating on UTF-8 strings.\n- `IntParser` (coming soon) for converting strings to integers.\n- `XMLBuilder` (coming soon) for assembling XML from dynamic parts.\n- `FormData` (coming soon) for decoding/encoding `application/x-www-form-urlencoded` strings.\n- `URLSearchParams` (coming soon) for decoding/encoding URL query strings.\n- `URL` (coming soon) for decoding/encoding URLs.\n- `Request` (later) for encoding HTTP/1 requests.\n- `Response` (later) for encoding HTTP/1 responses.\n- `Iterator` (coming soon) for creating a custom sequence type that can be iterated through.","ref":"readme.html"},{"type":"extras","title":"Installation - 🕸️🔋 SilverOrb: the standard library for <a href=\"https://github.com/RoyalIcing/Orb\">Orb</a>","doc":"The package can be installed by adding `silver_orb` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:silver_orb, \"~> 0.0.8\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Inspiration - 🕸️🔋 SilverOrb: the standard library for <a href=\"https://github.com/RoyalIcing/Orb\">Orb</a>","doc":"- https://www.rfleury.com/p/untangling-lifetimes-the-arena-allocator","ref":"readme.html#inspiration"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}